(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5314,        163]*)
(*NotebookOutlinePosition[      6029,        188]*)
(*  CellTagsIndexPosition[      5985,        184]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" Decision Structures that correspond to the MPL decision \
structures.",
    FontSize->14],
  "                                                                           \
    \n",
  StyleBox["This notebook corresponds to ",
    FontSize->14],
  "\n\n                                        Book:  ",
  StyleBox["Figure 1.3(a), page 6,\n                              Supplement- \
MPL's Decision Structures: Figure 3, page 4.\n                                \
        ",
    FontSize->14],
  "\nIn ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the relational operators are\n                 ===, <, >, < =, >=, =!= \
(for not equal).\n\nThe logical operators are \n               && (for  and)\n\
               || (for or),\n               ! (for not).\n\nA basic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["If",
    FontSlant->"Italic"],
  " structure has the form:\n\nIf[ logical expression, \n   statement 1;\n   \
statement 2;\n\n   statement n\n]\n\nTo obtain the MPL ",
  StyleBox["If-Else",
    FontSlant->"Italic"],
  " structure, use the form:\n\nIf [logical expression,\n   statement 1;\n   \
statement 2;\n\n   statement n,\n(*Else*)\n   statement 1;\n   statement 2;\n\
\n   statement n\n]\n\n Notice that a comma separates the",
  StyleBox[" If ",
    FontSlant->"Italic"],
  "section from the",
  StyleBox[" Else ",
    FontSlant->"Italic"],
  "section.\n For clarity, we have also separated the two sections with the \
comment\n  \n              (*Else*).\n              \nA multi-branch \
structure is obtained with the ",
  StyleBox["Which",
    FontSlant->"Italic"],
  " structure which has\nthe following form:\n\nWhich logical expression,\n   \
statement 1;\n   statement 2;\n\n   statement n,\n(*Elseif*) logical \
expression,\n   statement 1;\n   statement 2;\n\n   statement n,\n(*Else*)  \
True,\n   statement 1;\n   statement 2;\n\n   statement n\n]\n\nThe sections  \
of this structure are separated by commas, and for clarity\nwe have included \
the comments\n\n           (*Elseif*)     and     (*Else*).\n           \nA \
",
  StyleBox["Which",
    FontSlant->"Italic"],
  " structure can have zero or more",
  StyleBox[" Elseif",
    FontSlant->"Italic"],
  " sections and\nan optional",
  StyleBox[" Else",
    FontSlant->"Italic"],
  " section. Notice that the",
  StyleBox[" Else ",
    FontSlant->"Italic"],
  "section requires the logical\nconstant ",
  StyleBox["True",
    FontSlant->"Italic"],
  " at the beginning of the section.\n\n Example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x\  = \ 1/2\)], "Input"],

Cell[BoxData[
    \(1\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(If[\ 
      0\  \[LessEqual] \ x\  && \ 
        x\  \[LessEqual] \ 1, \[IndentingNewLine]\ \ \ \ \ \ f\  = \ 
        x^2 + 4, \[IndentingNewLine] (*Else*) \[IndentingNewLine]\ \ \ \ \ f\ \
 = \ x^2 - 1\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(17\/4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\)], "Input"],

Cell[BoxData[
    \(17\/4\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "An example that uses ",
  StyleBox["Elseif  ",
    FontSlant->"Italic"],
  "blocks is given in the ",
  StyleBox["Automatic_simplify",
    FontSlant->"Italic"],
  " procedure (see page 92) which is\nin the file",
  StyleBox[" \
MathematicalMethods/Programs/Mathematics/Ch3/AutomaticSimplify.txt.",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[""], "Input"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 680}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 2638, 66, 1387, "Text"],

Cell[CellGroupData[{
Cell[4380, 119, 44, 1, 30, "Input"],
Cell[4427, 122, 38, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4502, 128, 256, 5, 110, "Input"],
Cell[4761, 135, 39, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4837, 141, 34, 1, 30, "Input"],
Cell[4874, 144, 39, 1, 42, "Output"]
}, Open  ]],
Cell[4928, 148, 353, 11, 52, "Text"],
Cell[5284, 161, 26, 0, 30, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

