(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5103,        153]*)
(*NotebookOutlinePosition[      5818,        178]*)
(*  CellTagsIndexPosition[      5774,        174]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Iteration structures in ",
    FontSize->14],
  StyleBox["Mathematica",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" that correspond to those in MPL.\n\n                      Book: \
Figure 1.3 (b), page 6,\n                      Supplement - MPL's Iteration \
Structures, Figure 1, page 2. \n\n",
    FontSize->14],
  StyleBox["While Structures",
    FontVariations->{"Underline"->True}],
  "\n\nIn ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the relational operators are\n \n                ===, <, >, <=, >=, =!= \
(for not equal).\n\nThe logical operators are\n\n                   && (for \
and),\n                   || (for or),\n                   ! (for not).\n\nA \
simple ",
  StyleBox["Mathematica While",
    FontSlant->"Italic"],
  " loop has the form:\n\nWhile[ ",
  StyleBox["logical expression,",
    FontSlant->"Italic"],
  "\n    statement 1;\n    statement 2;\n         .\n    statement n\n]\n\n\
Example - computation of the first n+1\nterms of the Taylor series of u about\
\nx=a using a While loop."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u\  = \ Sin[x];\)\), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(n\  = \ 3;\)\), "\[IndentingNewLine]", 
    \(\(i = 1;\)\), "\[IndentingNewLine]", 
    \(\(s\  = \ ReplaceAll[u, x \[Rule] a];\)\), "\[IndentingNewLine]", 
    \(While[
      i \[LessEqual] n, \[IndentingNewLine]u\  = \ 
        D[u, x]; \[IndentingNewLine]s\  = \ 
        s + ReplaceAll[u, x \[Rule] a]/\(i!\)*\((x - a)\)^
              i; \[IndentingNewLine]i = i + 1]; s\)}], "Input"],

Cell[BoxData[
    \(x - x\^3\/6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["For Structures",
    FontVariations->{"Underline"->True}],
  "\n\nA simple ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " For loop has the form:\n\nFor[",
  StyleBox[" VariableName",
    FontSlant->"Italic"],
  " = ",
  StyleBox[" IntegerExpression1",
    FontSlant->"Italic"],
  ",  V",
  StyleBox["ariableName",
    FontSlant->"Italic"],
  " <=  I",
  StyleBox["ntegerExpression2, VariableName",
    FontSlant->"Italic"],
  "++,\n   statement 1;\n   statement 2;\n       .\n   statement n\n]\n\n\
Where ",
  StyleBox["IntegerExpression1",
    FontSlant->"Italic"],
  " is the initial value of ",
  StyleBox[" VariableName",
    FontSlant->"Italic"],
  " and ",
  StyleBox["IntegerExpression2",
    FontSlant->"Italic"],
  " is the final value.\nThe expression ",
  StyleBox["VariableName++",
    FontSlant->"Italic"],
  " indicates that ",
  StyleBox["VariableName",
    FontSlant->"Italic"],
  " increases by 1 with each pass through\nthe loop.\n\nExample - computation \
of the first N+1 terms of\nthe Taylor series of u about x=a using a For loop.\
\n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u\  = \ Sin[x];\)\), "\[IndentingNewLine]", 
    \(\(a\  = \ 0;\)\), "\[IndentingNewLine]", 
    \(\(n\  = \ 3;\)\), "\[IndentingNewLine]", 
    \(\(s\  = \ ReplaceAll[u, x \[Rule] a];\)\), "\[IndentingNewLine]", 
    \(\(For[i = 1, 
        i \[LessEqual] n, \(i++\), \[IndentingNewLine]u\  = \ 
          D[u, x]; \[IndentingNewLine]s\  = \ 
          s + ReplaceAll[u, x \[Rule] a]/\(i!\)*\((x - a)\)^
                i];\)\), "\[IndentingNewLine]", 
    \(s\)}], "Input"],

Cell[BoxData[
    \(x - x\^3\/6\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 680}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 1089, 27, 570, "Text"],

Cell[CellGroupData[{
Cell[2831, 80, 513, 10, 210, "Input"],
Cell[3347, 92, 45, 1, 45, "Output"]
}, Open  ]],
Cell[3407, 96, 1109, 37, 356, "Text"],

Cell[CellGroupData[{
Cell[4541, 137, 498, 10, 170, "Input"],
Cell[5042, 149, 45, 1, 45, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

