(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7369,        356]*)
(*NotebookOutlinePosition[      8085,        381]*)
(*  CellTagsIndexPosition[      8041,        377]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["The primitive structural operators in ",
    FontSize->14],
  StyleBox["Mathematica",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSize->14],
  StyleBox["that are most similar to those in MPL.\nThis notebook corresponds \
to\n\n                      Book: ",
    FontSize->14,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Figure 1-6(a), page 9, \n                      Supplement - \
Primitive Structural Operators: Figure 1, page 3.",
    FontSize->14],
  StyleBox["\n",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox["\nMathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Head ",
    FontSlant->"Italic"],
  "operator is similar to MPL's ",
  StyleBox["Kind",
    FontSlant->"Italic"],
  " operator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[x]\)], "Input"],

Cell[BoxData[
    \(Symbol\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[3]\)], "Input"],

Cell[BoxData[
    \(Integer\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[a + b]\)], "Input"],

Cell[BoxData[
    \(Plus\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[a/b]\)], "Input"],

Cell[BoxData[
    \(Times\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[2/3]\)], "Input"],

Cell[BoxData[
    \(Rational\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[a + b \[Equal] c]\)], "Input"],

Cell[BoxData[
    \(Equal\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the braces { and } for both sets and lists:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[{a, b, c}]\)], "Input"],

Cell[BoxData[
    \(List\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[a\ \  && \ b]\)], "Input"],

Cell[BoxData[
    \(And\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[Sin[x]]\)], "Input"],

Cell[BoxData[
    \(Sin\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Length",
    FontSlant->"Italic"],
  " operator is similar to MPL's\n",
  StyleBox["Number_of_operands ",
    FontSlant->"Italic"],
  "operator:\n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[m*x + b]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[f[x, y]]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[{a, b, c, d}]\)], "Input"],

Cell[BoxData[
    \(4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[\(n!\)]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s",
  StyleBox[" Part ",
    FontSlant->"Italic"],
  "operator is similar to MPL's\n",
  StyleBox["Operand ",
    FontSlant->"Italic"],
  "operator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[x^2, 1]\)], "Input"],

Cell[BoxData[
    \(x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[x^2, 2]\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[{a, b, c}, 3]\)], "Input"],

Cell[BoxData[
    \(c\)], "Output"]
}, Open  ]],

Cell["", "Text"],

Cell[TextData[{
  "Keep in mind, because automatic simplification in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\nmay apply the commutative law to reorder the operands in a\nsum or \
product, the ",
  StyleBox["Part",
    FontSlant->"Italic"],
  " operator may return an unexpected result.\nFor example:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[b + a, 1]\)], "Input"],

Cell[BoxData[
    \(a\)], "Output"]
}, Open  ]],

Cell["\<\
In this example, b+a is reordered to a+b by automatic simplification.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Notice that the ",
    FontFamily->"Times New Roman"],
  StyleBox["Part",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" command cannot be used to obtain the numerator and denominator \
of a fraction.  \nUse the ",
    FontFamily->"Times New Roman"],
  StyleBox["Numerator",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  StyleBox["Denominator",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" commands instead.\n",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Part[2/\((\(-3\))\), 1]\)], "Input"],

Cell[BoxData[
    \(Part::"partd" \(\(:\)\(\ \)\) 
      "Part specification \!\(\(\((\(-\(\(2\/3\)\)\))\)\) \
\[LeftDoubleBracket] 1 \[RightDoubleBracket]\) is longer than depth of \
object."\)], "Message"],

Cell[BoxData[
    \(\((\(-\(2\/3\)\))\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Denominator[2/\((\(-3\))\)]\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s",
  StyleBox[" Apply ",
    FontSlant->"Italic"],
  "operator is similar to MPL's ",
  StyleBox["Construct",
    FontSlant->"Italic"],
  " operator:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[Plus, {a, b, c}]\)], "Input"],

Cell[BoxData[
    \(a + b + c\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Apply[f, {x, y}]\)], "Input"],

Cell[BoxData[
    \(f[x, y]\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 680}},
WindowSize->{1016, 648},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 796, 27, 152, "Text"],

Cell[CellGroupData[{
Cell[2538, 80, 40, 1, 30, "Input"],
Cell[2581, 83, 40, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2658, 89, 40, 1, 30, "Input"],
Cell[2701, 92, 41, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2779, 98, 44, 1, 30, "Input"],
Cell[2826, 101, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2901, 107, 42, 1, 30, "Input"],
Cell[2946, 110, 39, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3022, 116, 42, 1, 30, "Input"],
Cell[3067, 119, 42, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3146, 125, 55, 1, 30, "Input"],
Cell[3204, 128, 39, 1, 29, "Output"]
}, Open  ]],
Cell[3258, 132, 133, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[3416, 140, 48, 1, 30, "Input"],
Cell[3467, 143, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3542, 149, 51, 1, 30, "Input"],
Cell[3596, 152, 37, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3670, 158, 45, 1, 30, "Input"],
Cell[3718, 161, 37, 1, 29, "Output"]
}, Open  ]],
Cell[3770, 165, 248, 10, 71, "Text"],

Cell[CellGroupData[{
Cell[4043, 179, 48, 1, 30, "Input"],
Cell[4094, 182, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4166, 188, 48, 1, 30, "Input"],
Cell[4217, 191, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4289, 197, 53, 1, 30, "Input"],
Cell[4345, 200, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4417, 206, 47, 1, 30, "Input"],
Cell[4467, 209, 35, 1, 29, "Output"]
}, Open  ]],
Cell[4517, 213, 241, 11, 71, "Text"],

Cell[CellGroupData[{
Cell[4783, 228, 45, 1, 30, "Input"],
Cell[4831, 231, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4903, 237, 45, 1, 30, "Input"],
Cell[4951, 240, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5023, 246, 51, 1, 30, "Input"],
Cell[5077, 249, 35, 1, 29, "Output"]
}, Open  ]],
Cell[5127, 253, 16, 0, 33, "Text"],
Cell[5146, 255, 331, 9, 90, "Text"],

Cell[CellGroupData[{
Cell[5502, 268, 47, 1, 30, "Input"],
Cell[5552, 271, 35, 1, 29, "Output"]
}, Open  ]],
Cell[5602, 275, 93, 2, 33, "Text"],
Cell[5698, 279, 615, 19, 71, "Text"],

Cell[CellGroupData[{
Cell[6338, 302, 56, 1, 30, "Input"],
Cell[6397, 305, 207, 4, 36, "Message"],
Cell[6607, 311, 97, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6741, 318, 60, 1, 30, "Input"],
Cell[6804, 321, 35, 1, 29, "Output"]
}, Open  ]],
Cell[6854, 325, 243, 11, 52, "Text"],

Cell[CellGroupData[{
Cell[7122, 340, 55, 1, 30, "Input"],
Cell[7180, 343, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7260, 349, 49, 1, 30, "Input"],
Cell[7312, 352, 41, 1, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

