(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4669,        199]*)
(*NotebookOutlinePosition[      5384,        224]*)
(*  CellTagsIndexPosition[      5340,        220]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Structure-based operators in ",
    FontSize->14],
  StyleBox["Mathematica",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" that are most similar to those in MPL.\nThis notebook \
corresponds to\n\n                    Book: Figure 1.6(b), page 9,\n          \
          Supplement - Structural-based Operators: Figure 2, page 2.\n\n",
    FontSize->14],
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operator that corresponds \nmost closely to MPL's ",
  StyleBox["Free_of",
    FontSlant->"Italic"],
  " operator is the ",
  StyleBox["FreeQ",
    FontSlant->"Italic"],
  " operator."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[a + b, b]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[a + b, \ c]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[\((a + b)\)*c, \ a + b]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[Sin[x] + 2*x, Sin[x]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica's",
    FontSlant->"Italic"],
  " ",
  StyleBox["FreeQ",
    FontSlant->"Italic"],
  " operator can also test for incomplete sub-expressions. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[\((a + b + c)\)*d, \ a + b]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In the next example, automatic simplification in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " transforms\nthe expression so that ",
  StyleBox["FreeQ",
    FontSlant->"Italic"],
  " returns True."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FreeQ[\((x*y)\)^2, x*y]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\n The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operator that corresponds most closely to MPL's \\\n",
  StyleBox["Substitute",
    FontSlant->"Italic"],
  " operator is the",
  StyleBox[" ReplaceAll",
    FontSlant->"Italic"],
  " operator.  \n"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReplaceAll[a + b, \ b -> x]\)], "Input"],

Cell[BoxData[
    \(a + x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReplaceAll[1/a + a, \ a -> x]\)], "Input"],

Cell[BoxData[
    \(1\/x + x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReplaceAll[\((a + b)\)^2 + 1, a + b -> x]\)], "Input"],

Cell[BoxData[
    \(1 + x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ReplaceAll operator can substitute for incomplete sub-expressions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReplaceAll[a + b + c, a + b -> x]\)], "Input"],

Cell[BoxData[
    \(c + x\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 680}},
WindowSize->{792, 500},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 654, 20, 172, "Text"],

Cell[CellGroupData[{
Cell[2396, 73, 48, 1, 30, "Input"],
Cell[2447, 76, 39, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2523, 82, 50, 1, 30, "Input"],
Cell[2576, 85, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2651, 91, 62, 1, 30, "Input"],
Cell[2716, 94, 39, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2792, 100, 60, 1, 30, "Input"],
Cell[2855, 103, 39, 1, 29, "Output"]
}, Open  ]],
Cell[2909, 107, 195, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[3129, 118, 66, 1, 30, "Input"],
Cell[3198, 121, 39, 1, 29, "Output"]
}, Open  ]],
Cell[3252, 125, 241, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[3518, 137, 56, 1, 30, "Input"],
Cell[3577, 140, 38, 1, 29, "Output"]
}, Open  ]],
Cell[3630, 144, 295, 11, 90, "Text"],

Cell[CellGroupData[{
Cell[3950, 159, 60, 1, 30, "Input"],
Cell[4013, 162, 39, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4089, 168, 62, 1, 30, "Input"],
Cell[4154, 171, 42, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4233, 177, 74, 1, 30, "Input"],
Cell[4310, 180, 42, 1, 29, "Output"]
}, Open  ]],
Cell[4367, 184, 153, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[4545, 192, 66, 1, 30, "Input"],
Cell[4614, 195, 39, 1, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

